/* Background key colors */
.trx_bg_colors {
  position: fixed;
  z-index: -1;
  top: 0;
  left: 0;
  right: 0;
  bottom: 0;
  width: 100%;
  height: 100%;
  pointer-events: none;
}

body.with_bg_colors .page_content_wrap, body.with_bg_colors.body_style_boxed .page_wrap {
  background-color: transparent;
}

/*# sourceMappingURL=bg-colors.css.map */
